==> kdebase-4.4.3-i486-1.txz: install/doinst.sh <==
#!/bin/sh
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi
( cd usr/lib ; rm -rf libkonq.so.5 )
( cd usr/lib ; ln -sf libkonq.so.5.4.0 libkonq.so.5 )
( cd usr/lib ; rm -rf libdolphinprivate.so )
( cd usr/lib ; ln -sf libdolphinprivate.so.4 libdolphinprivate.so )
( cd usr/lib ; rm -rf libkonquerorprivate.so )
( cd usr/lib ; ln -sf libkonquerorprivate.so.4 libkonquerorprivate.so )
( cd usr/lib ; rm -rf libkonq.so )
( cd usr/lib ; ln -sf libkonq.so.5 libkonq.so )
( cd usr/lib ; rm -rf libkonqsidebarplugin.so.4 )
( cd usr/lib ; ln -sf libkonqsidebarplugin.so.4.4.0 libkonqsidebarplugin.so.4 )
( cd usr/lib ; rm -rf libdolphinprivate.so.4 )
( cd usr/lib ; ln -sf libdolphinprivate.so.4.4.0 libdolphinprivate.so.4 )
( cd usr/lib ; rm -rf libkonquerorprivate.so.4 )
( cd usr/lib ; ln -sf libkonquerorprivate.so.4.4.0 libkonquerorprivate.so.4 )
( cd usr/lib ; rm -rf libkonqsidebarplugin.so )
( cd usr/lib ; ln -sf libkonqsidebarplugin.so.4 libkonqsidebarplugin.so )
( cd usr/share/doc/HTML/en/konqueror ; rm -rf common )
( cd usr/share/doc/HTML/en/konqueror ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/en/kwrite ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfind ; rm -rf common )
( cd usr/share/doc/HTML/en/kfind ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/dolphin ; rm -rf common )
( cd usr/share/doc/HTML/en/dolphin ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/interrupts ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/interrupts ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/samba ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/samba ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/protocols ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/protocols ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/ioports ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/ioports ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/sound ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/sound ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/nics ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/nics ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/opengl ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/opengl ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/xserver ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/xserver ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/partitions ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/partitions ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/processor ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/processor ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/scsi ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/scsi ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/memory ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/memory ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/dma ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/dma ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/usb ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/usb ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/view1394 ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/view1394 ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/pci ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/pci ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kinfocenter/devices ; rm -rf common )
( cd usr/share/doc/HTML/en/kinfocenter/devices ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kdepasswd ; rm -rf common )
( cd usr/share/doc/HTML/en/kdepasswd ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konsole ; rm -rf common )
( cd usr/share/doc/HTML/en/konsole ; ln -sf /usr/share/doc/HTML/en/common common )

==> kdebase-4.5.5-i486-3.txz: install/doinst.sh <==
#!/bin/sh
if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database /usr/share/applications >/dev/null 2>&1
fi
( cd usr/share/doc/HTML/en/kdepasswd ; rm -rf common )
( cd usr/share/doc/HTML/en/kdepasswd ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/dolphin ; rm -rf common )
( cd usr/share/doc/HTML/en/dolphin ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kwrite ; rm -rf common )
( cd usr/share/doc/HTML/en/kwrite ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konqueror ; rm -rf common )
( cd usr/share/doc/HTML/en/konqueror ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/konsole ; rm -rf common )
( cd usr/share/doc/HTML/en/konsole ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kfind ; rm -rf common )
( cd usr/share/doc/HTML/en/kfind ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/lib ; rm -rf libdolphinprivate.so )
( cd usr/lib ; ln -sf libdolphinprivate.so.4 libdolphinprivate.so )
( cd usr/lib ; rm -rf libkbookmarkmodel_private.so )
( cd usr/lib ; ln -sf libkbookmarkmodel_private.so.4 libkbookmarkmodel_private.so )
( cd usr/lib ; rm -rf libkonq.so )
( cd usr/lib ; ln -sf libkonq.so.5 libkonq.so )
( cd usr/lib ; rm -rf libkonq.so.5 )
( cd usr/lib ; ln -sf libkonq.so.5.5.0 libkonq.so.5 )
( cd usr/lib ; rm -rf libkonqsidebarplugin.so.4 )
( cd usr/lib ; ln -sf libkonqsidebarplugin.so.4.5.0 libkonqsidebarplugin.so.4 )
( cd usr/lib ; rm -rf libkonquerorprivate.so.4 )
( cd usr/lib ; ln -sf libkonquerorprivate.so.4.5.0 libkonquerorprivate.so.4 )
( cd usr/lib ; rm -rf libdolphinprivate.so.4 )
( cd usr/lib ; ln -sf libdolphinprivate.so.4.5.0 libdolphinprivate.so.4 )
( cd usr/lib ; rm -rf libkbookmarkmodel_private.so.4 )
( cd usr/lib ; ln -sf libkbookmarkmodel_private.so.4.5.0 libkbookmarkmodel_private.so.4 )
( cd usr/lib ; rm -rf libkonquerorprivate.so )
( cd usr/lib ; ln -sf libkonquerorprivate.so.4 libkonquerorprivate.so )
( cd usr/lib ; rm -rf libkonqsidebarplugin.so )
( cd usr/lib ; ln -sf libkonqsidebarplugin.so.4 libkonqsidebarplugin.so )
